====================
The publication page
====================

The `publication page <https://pesummary.github.io/GW190412/html/Publication.html>`_
displays a selection of plots which are typically displayed in LIGO publications.
This includes, violin plots, spin disks and bounded 2d contour plots. Under each
image is a caption button (describing the plot) and a command line button,
which provides the `summarypublication <../../core/cli/summarypublication.html>`_
command line to generate the plot.
